***Targeting II Paper***
* Figure 5. Comparison of Self-Selection and Hypothetical Universal Automatic Targeting
* Note: the fanreg command must be installed, and STATA must be running with administrator rights
* http://eml.berkeley.edu/~webfac/emiguel/e270c_s09/ps1.ado.txt

/*
Notation:

ST = self targeting
AE = automatic enrollment 
HUAE = hypothetical universal EA

1 - use govt data
2 - use mixed data (govt data on those who show up, baseline data on the rest)
3 - use baseline data on everyone
*/

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

* Data

use "data\codeddata\baseline\matched_baseline.dta", clear

*** ST3 versus HUAE3 in AE sample using suseti poverty line and noisy PMT
	gen     getbenefit_hypothetical = (pcexppred_noise<povertyline3_noise)
	replace getbenefit_hypothetical = 0 if showup==0 & selftargeting==1

tab getbenefit_hyp selft

tempfile coded
save 	`coded'

* Kolmogorov-Smirnov test
clear
set obs 1000
gen num=_n
gen random=.
gen true=.
tempfile ks_test
sa `ks_test', replace

use `coded', clear

*** Kolmogorov-Smirnov test
noisily ksmirnov logconsumption if getbenefit_hypothetical==1 , by(selftargeting) exact
local true=r(D)

*** randomization inference
local i=1
set seed 100
qui while `i'<=1000 {
	use "data\codeddata\baseline\matched_baseline.dta", clear
	duplicates drop hhea, force
	gen temp=runiform()   /*randomly sort the villages*/
	sort temp
	gen ST_temp=(_n<=200) /*randomly assign 200 to self-targeting*/
	keep hhea ST_temp
	merge 1:m hhea using `coded'
	assert _merge==3
	drop _merge
	
	ksmirnov logconsumption if getbenefit_hypothetical==1 , by(ST_temp) exact
	local random=r(D)
	u `ks_test', clear
	replace random=`random' if num==`i'
	sa `ks_test', replace
	
	local i =`i' + 1
}

u `ks_test', clear
replace true=`true'
drop num
sort random
gen temp1=(true<=random)
egen temp2=total(temp1)
gen double p_value=temp2/1000
noi di "p-value of the K-S test: " p_value
pause


***

pause off

use `coded', clear

* Figure 5A: CDF benefeciaries
cumul logconsumption if getbenefit_hypothetical==1 & maintreatment==1,gen(bene_cons_PMT)
cumul logconsumption if getbenefit_hypothetical==1 & maintreatment==2,gen(bene_cons_ST)

graph twoway (line bene_cons_PMT logconsumption,sort lpattern(solid) ///
	color(orange) lwidth(thick)) (line bene_cons_ST logconsumption, ///
	sort color(black) lwidth(thick)) , xtitle("Log Consumption") ///
	ytitle("CDF")  ylabel(0(0.2)1) xscale(range(11 15)) xlabel(11(1)15) ///
	yscale(range(0 1))legend(label(1 "Hypothetical Universal Automatic Targeting") ///
	label(2 "Self-Targeting") row(1) size(small) width(120)) ///
	graphregion(color(white)) bgcolor(white)
	
graph save   "figures\Figure 5a.gph", replace
graph export "figures\Figure 5a.eps", replace


* Figure 5B: probability to receive benefits under the two treatments, as fn of logconsumption
pause off
set seed 100
	qui fanreg getbenefit_hypothetical logconsumption if maintreatment==1,reps(500) bw(10) np(50) maxminon max(0.4) min(0) xgen ("temp1") ygen("passed_cons_PMT") cluster(hhea)
set seed 100
	qui fanreg getbenefit_hypothetical logconsumption if maintreatment==2,reps(500) bw(10) np(50) maxminon max(0.4) min(0) xgen ("temp2") ygen("passed_cons_ST") cluster(hhea)
qui{
replace passed_cons_PMT  =. if passed_cons_PMT   <0
replace passed_cons_ST   =. if passed_cons_ST    <0
replace passed_cons_PMT_u=. if passed_cons_PMT_u <0
replace passed_cons_ST_u =. if passed_cons_ST_u  <0
replace passed_cons_PMT_l=. if passed_cons_PMT_l <0
replace passed_cons_ST_l =. if passed_cons_ST_l  <0
}

twoway (line passed_cons_PMT temp1, sort col(orange)) ///
	(line  passed_cons_PMT_u temp1, sort clpat(dot) col(orange)) ///
	(line  passed_cons_PMT_l temp1, sort clpat(dot) col(orange))  ///
	(line  passed_cons_ST temp2, sort col(black)) ///
	(line passed_cons_ST_u temp2,sort clpat(dot) col(black)) ///
	(line passed_cons_ST_l temp2,sort clpat(dot) col(black)), ///
	xtitle("Log Consumption") ytitle("Probability to Receive Benefits") yscale(range(0 0.4)) ///
	ylabel(0(0.1)0.4) xscale(range(11 15)) xlabel(11(1)15) ///
	legend( order (1 4) label(1 "Automatic Screening") ///
	label(4 "Self-Targeting")) graphregion(color(white)) bgcolor(white)
	
graph save   "figures\Figure 5b.gph", replace
graph export "figures\Figure 5b.eps", replace

