* Online Appendix Figure C3. Comparison of Self-Selection and Hypothetical Universal Automatic Targeting
* Version of Figure 5 using bootstrap and many random noise values

/*
Notation:

ST = self targeting
AE = automatic enrollment 
HUAE = hypothetical universal EA

1 - use govt data
2 - use mixed data (govt data on those who show up, baseline data on the rest)
3 - use baseline data on everyone
*/

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"


** Panel A - CDF

use "data\codeddata\baseline\matched_baseline.dta", clear

* drop noise and old noisy pmt score
drop PMTSCORE_noise pcexppred_noise

* Number of bootstrap iterations
local bootstrapruns=100

gen ks_test = .

qui forv x = 1/`bootstrapruns' {
	noi di "Bootstrap run no `x'"
	
* boostrap clustered at village level
	preserve
		bsample, cluster(hhea)
		sort hhid

	* generate noise and add to PMT score
	* using noise standard deviation = 0.45
	* see paper for details	
		gen noise = rnormal(0,0.45)
	
		gen PMTSCORE_noise = PMTSCORE + noise
		gen pce_sim = exp(PMTSCORE_noise)
		
	* getbenefit if qualify based on noisy PMT, and showed up if in ST 
		gen     getbenefit_h = pce_sim < povertyline3_noise_smooth
		replace getbenefit_h = 0 if showup==0 & selftargeting==1
		
	* KS test
		qui ksmirnov logconsumption if getbenefit_h==1 , by(selftargeting) exact
		local kstest=r(D)
		
	* CDF benefeciaries
		cumul logconsumption if getbenefit_h==1 & maintreatment==1, gen(cdf_pmt`x')
		cumul logconsumption if getbenefit_h==1 & maintreatment==2, gen(cdf_st`x')
		
		keep hhid logconsumption cdf_pmt`x' cdf_st`x'
		
		* same level of logconsumption appears multiple times (due to boostrap)
		* take average value of CDF
		collapse (mean) cdf_pmt`x' cdf_st`x', by(hhid logconsumption)
		
		tempfile bootx
		save	`bootx', replace
	restore
	
	* kstest
	replace ks_test = `kstest' in `x'
	
	* merge cdf's for the current bootstrap iteration
	merge 1:1 hhid using `bootx'
	assert _m!=2
	drop _m
	
	sort logconsumption
	
	* interpolate CDF values
		ipolate cdf_pmt`x' logconsumption , generate(temp) epolate
		drop cdf_pmt`x'
		rename temp cdf_pmt`x'
		replace cdf_pmt`x'=1 if cdf_pmt`x'>1
		replace cdf_pmt`x'=0 if cdf_pmt`x'<0
			
		ipolate cdf_st`x' logconsumption , generate(temp) epolate
		drop cdf_st`x'
		rename temp cdf_st`x'
		replace cdf_st`x'=1 if cdf_st`x'>1
		replace cdf_st`x'=0 if cdf_st`x'<0

}


* average the bootstrap CDFs
	egen cdf_st  = rowmean(cdf_st*)
	egen cdf_pmt = rowmean(cdf_pmt*)

	graph twoway (line cdf_pmt logconsumption,sort lpattern(solid) ///
		color(orange) lwidth(thick)) (line cdf_st logconsumption, ///
		sort color(black) lwidth(thick)) , xtitle("Log Consumption") ///
		ytitle("CDF")  ylabel(0(0.2)1) xscale(range(11 15)) xlabel(11(1)15) ///
		yscale(range(0 1))legend(label(1 "Hypothetical Universal Automatic Targeting") ///
		label(2 "Self-Targeting") row(1) size(small) width(120)) ///
		graphregion(color(white)) bgcolor(white)
	
	graph save   "figures\Online Appendix Figure C3a.gph", replace
	graph export "figures\Online Appendix Figure C3a.eps", replace

	tempfile cdfs	
	save	`cdfs'


* randomization inference for the KS test
	* list of villages
		use "data\codeddata\baseline\matched_baseline.dta", clear
		keep hhea
		duplicates drop hhea, force
		tempfile villages
		save	`villages'
	
	* basic household data
		use "data\codeddata\baseline\matched_baseline.dta", clear
		keep hhid hhea PMTSCORE povertyline3_noise_smooth showup selftargeting logconsumption
		sort hhid
		tempfile hhds
		save	`hhds'
	
	* number of iterations for randomized inference
		local rinfn = 300

	set seed 228347
	qui forv i=1/`rinfn'{
		noi di "Randomized inference run no `i' out of `rinfn'"
		preserve
			use `villages', clear
			gen  temp=runiform()   /*randomly sort the villages*/
			sort temp
			gen ST_temp=(_n<=200) /*randomly assign 200 to self-targeting*/
			keep hhea ST_temp
			tempfile villages_rand
			save	`villages_rand', replace
		restore
		
		* bootstrap sample
		use `hhds', clear
		bsample, cluster(hhea)

	* generate noise and add to PMT score	
		gen noise = rnormal(0,0.45)
	
		gen PMTSCORE_noise = PMTSCORE + noise
		gen pce_sim = exp(PMTSCORE_noise)
		
	* getbenefit if qualify based on noisy PMT, and showed up if in ST 
		gen     getbenefit_h = pce_sim < povertyline3_noise_smooth
		replace getbenefit_h = 0 if showup==0 & selftargeting==1
		
	* add **randomly** assigned selftargeting treatment	
		merge m:1 hhea using `villages_rand'
		keep if _m==3
		drop    _m
		
		ksmirnov logconsumption if getbenefit_h==1 , by(ST_temp) exact
		local ks`i'=r(D)
	}

	use `cdfs', clear
	
	gen ks_rand=.
	forv i=1/`rinfn'{
		replace ks_rand = `ks`i'' in `i'
	}
		
	* p-value corresponding to the average KS test
	sum ks_test
	count if ks_rand <. & ks_rand > r(mean)
	local p_value = r(N)/`rinfn'
	noi di "p-value of the randomized inference K-S test: " `p_value'

// */
	
	
	
** Panel B - probability to receive benefits under the two treatments, as fn of logconsumption

use "data\codeddata\baseline\matched_baseline.dta", clear

* drop noise and old noisy pmt score
drop PMTSCORE_noise pcexppred_noise

* get unique logconsumption values 
preserve
	keep logc
	rename logc logc_orig
	duplicates drop
	drop if logc_orig==.
	tempfile orig_logc
	save 	`orig_logc'
restore

* Number of bootstrap iterations
local bootstrapruns=100

qui forv x = 1/`bootstrapruns' {
	noi di "Bootstrap run no `x'"
	
* boostrap sample
	preserve
		bsample, cluster(hhea)
		sort hhid

	* generate noise and add to PMT score
	* using noise standard deviation = 0.45
	* see paper for details	
		gen noise = rnormal(0,0.45)
	
		gen PMTSCORE_noise = PMTSCORE + noise
		gen pce_sim = exp(PMTSCORE_noise)
		
	* getbenefit if qualify based on noisy PMT, and showed up if in ST 
		gen     getbenefit_h = pce_sim < povertyline3_noise_smooth
		replace getbenefit_h = 0 if showup==0 & selftargeting==1
		
	* add original log consumption distribution
		append using `orig_logc', gen(logc_orig_sample)
		
	* probability to get benefits
		lpoly getbenefit_h logconsumption if logc_orig_sample==0 & maintreatment==1, nograph at(logc_orig) generate(get_PMT_`x') bw(0.15)
		lpoly getbenefit_h logconsumption if logc_orig_sample==0 & maintreatment==2, nograph at(logc_orig) generate(get_ST_`x')  bw(0.15)
		
		keep if logc_orig_sample==1
		keep logc_orig get_*_`x'
		rename logc_orig logconsumption
		
		tempfile bootx
		save	`bootx', replace
	restore
		
	* merge result for the current bootstrap iteration
	merge m:1 logconsumption using `bootx'
	assert _m!=2
	drop _m

}

* define estimated local linear regression, and (cluster boostrapped) point-wise error bands
* trim error bands at 0 and 0.4
egen prob_get_PMT = rowmean(get_PMT*)
egen prob_get_PMT_sd = rowsd(get_PMT*)
gen prob_get_PMT_l = max(0  , prob_get_PMT - 1.96*prob_get_PMT_sd)
gen prob_get_PMT_u = min(0.4, prob_get_PMT + 1.96*prob_get_PMT_sd)

egen prob_get_ST = rowmean(get_ST*)
egen prob_get_ST_sd = rowsd(get_ST*)
gen prob_get_ST_l = max(0  , prob_get_ST - 1.96*prob_get_ST_sd)
gen prob_get_ST_u = min(0.4, prob_get_ST + 1.96*prob_get_ST_sd)

sort logc 
twoway (line prob_get_PMT logc, sort col(orange)) ///
	(line  prob_get_PMT_u logc, sort clpat(dot) col(orange)) ///
	(line  prob_get_PMT_l logc, sort clpat(dot) col(orange))  ///
	(line  prob_get_ST  logc, sort col(black)) ///
	(line prob_get_ST_u logc, sort clpat(dot) col(black)) ///
	(line prob_get_ST_l logc, sort clpat(dot) col(black)), ///
	xtitle("Log Consumption") ytitle("Probability to Receive Benefits") yscale(range(0 0.4)) ///
	ylabel(0(0.1)0.4) xscale(range(11 15)) xlabel(11(1)15) ///
	legend( order (1 4) label(1 "Automatic Screening") ///
	label(4 "Self-Targeting")) graphregion(color(white)) bgcolor(white)

	graph save   "figures\Online Appendix Figure C3b.gph", replace
	graph export "figures\Online Appendix Figure C3b.eps", replace
