* Online Appendix Table C.4. Factors Predicting Show Up (Logit)
* Online Appendix Table C.5. Factors Predicting Show Up (OLS)

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data/Prep Variables

*** Groups and times
	u "data\originaldata\Baseline\hh_pm2.dta", clear
	bys hhid: egen numactivities = max(pm03_line)
	bys hhid: egen activityhours = total(pm05)
	keep hhid numactivities activityhours
	duplicates drop
	tempfile activities
	save	`activities'

*** Leader connections
	u "data\originaldata\Baseline\hh_pm3.dta", clear
	keep if pm2type=="a"
	isid hhid
	g leaderconnect1 = (pm13=="A" | pm13=="B")
	la var leaderconnect1 "Closely related to village head"
	g leaderconnect2 = pm12==1
	la var leaderconnect2 "Friends/relatives with village head"
	drop leaderconnect2	
	keep hhid leaderconnect*
	tempfile leader
	sa 		`leader'

*** Education level
	u "data\originaldata\Baseline\hh_krt.dta"
	keep hhid krt05 krt08*
	replace krt05 = 0 if krt05==3
	recode krt08x (95=0) (98=.)
	ren krt05 HH_head_canread
	ren krt08x HH_head_borninvill
	ren krt08 HH_yrs_since_moved_in
	replace HH_yrs_since_moved_in = 100 if HH_yrs_since_moved_in==. & HH_head_bornin==1
	tempfile hhhead
	sa      `hhhead'

*** Other benefits
	u "data\originaldata\baseline\hh_ksr1.dta", clear
	recode ksr01 (3=0)
	drop ksr01a ksr01ax
	reshape wide ksr01, i(hhid) j(ksr1type) string
	ren ksr01a askeskin
	ren ksr01b raskin
	ren ksr01c blt
	tempfile benefits
	sa 		`benefits'

*** Shocks
	u "data\originaldata\baseline\hh_ge.dta", clear
	g shocks = ge01==1
	collapse (sum) shocks, by(hhid)
	tempfile shocks
	save	`shocks'


*** Subjective welfare
	u "data\originaldata\baseline\hh_sw.dta", clear
	recode sw02 (8=.)
	recode sw03 (7=.)
	ren sw01 happiness
	ren sw02 selfwealth
	ren sw03 selfcompwealth
	tempfile subj
	save	`subj'

*** Widow, sector, and highest ed achieved
	u "data\originaldata\baseline\hh_ar2.dta", clear
	keep if ar00==1
	keep hhid ar03 ar06 ar08 ar17 ar18
	* Widow
	g widow=ar06==4&ar03==3
	drop ar03 ar06
	* Sector
	g sect_agriculture = ar08==1
	g sect_plantation = ar08==2
	g sect_livestock = ar08==3
	g sect_fisheries = ar08==4
	g sect_hunting = ar08==5
	g sect_mining = ar08==6
	g sect_manufacturing = ar08==7
	g sect_utilities = ar08==8
	g sect_ctruction = ar08==9
	g sect_service_sales = ar08==10
	g sect_transportation = ar08==11
	g sect_financial_services = ar08==12
	g sect_social_services = ar08==13
	g sect_look_after_hh = ar08==14
	g sect_other = ar08==95
	drop sect_other
	drop ar08
	* Education level
	g yearsed = 0 if ar17==0
	replace yearsed = ar18 if ar18>=1 & ar18<=6
	replace yearsed = 6 if (ar17==2 | ar17==5) & yearsed==.
	replace yearsed = 9 if ar17==3 | ar17==6
	replace yearsed = 12 if ar17==4 | ar17==7
	replace yearsed = 14 if ar17==8
	replace yearsed = 16 if ar17==9
	replace yearsed = 18 if ar17==10
	drop ar17 ar18
	tempfile sector
	save	`sector'

*** Epsilon
	use "data\codeddata\baseline\matched_baseline.dta",clear 

	keep if maintreatment==2
	*generate epsilon=logconsumption-PMTSCORE
	reg logconsumption PMTSCORE, cl(hhea)
	predict p_logconsumption
	gen epsilon=logconsumption-p_logconsumption

*** Merge data
	merge 1:1 hhid using `activities'
	drop if _m==2
	drop _m
	merge 1:1 hhid using `leader'
	assert _m!=1
	drop if _m==2
	drop _m
	merge 1:1 hhid using `hhhead'
	assert _m!=1
	drop if _m==2
	drop _m
	merge 1:1 hhid using `benefits'
	assert _m!=1
	drop if _m==2
	drop _m
	merge 1:1 hhid using `shocks'
	assert _m!=1
	drop if _m==2
	drop _m
	merge 1:1 hhid using `subj'
	assert _m!=1
	drop if _m==2
	drop _m
	merge 1:1 hhid using `sector'
	assert _m!=1
	drop if _m==2
	drop _m

	replace numactivities = 0 if numactivities==.
	replace activityhours = 0 if activityhours==.

	order PMTSCORE epsilon numactivities activityhours leaderconnect* raskin askeskin blt selfwealth shocks widow sect_* //facilitatorFE*

	tempfile data
	sa `data'

***

**** Create Tables 
forv x = 1/2 {
	if `x'==2 keep if pcexppred<povertyline3
	* Panel A = All Households; Panel B = Eligible bt PMT Score
	local a : word `x' of OLS_A OLS_B 
	local b : word `x' of Logit_A Logit_B

*** Regressions: OLS (Appendix Table C5)
reg showup PMTSCORE epsilon selfwealth, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') replace groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

reg showup PMTSCORE epsilon numactivities activityhours , cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

reg showup PMTSCORE epsilon leaderconnect* , cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

reg showup PMTSCORE epsilon raskin askeskin blt, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

reg showup PMTSCORE epsilon shocks, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

reg showup PMTSCORE epsilon widow, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

reg showup PMTSCORE epsilon yearsed, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

areg showup PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed, cl(hhea) ab(kecagroup)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed) 




*** Regressions: logit (Appendix Table C4)
version 10: logit showup PMTSCORE epsilon selfwealth, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'", se bdec(3) addstat("mean of dep var", `m1') replace groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon numactivities activityhours , cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon leaderconnect* , cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon raskin askeskin blt, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon shocks, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon widow, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon yearsed, cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)

version 10: logit showup PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed , cl(hhea)
sum showup if e(sample)
local m1 = `r(mean)'
outreg2 using "tables\Online Appendix Table C45_`b'",excel se bdec(3) addstat("mean of dep var", `m1') append groupvar(PMTSCORE epsilon selfwealth numactivities activityhours leaderconnect* raskin askeskin blt shocks widow yearsed)



}

