*** Online Appendix Table C.8: 
*** Comparison of Targeting under Self-Selection and Hypothetical Universal Automatic Targeting using Baseline Data
*** Version of Table 6 using bootstrap and many random noise values

/*
Notation:

ST = self targeting
AE = automatic enrollment 
HUAE = hypothetical universal EA

1 - use govt data
2 - use mixed data (govt data on those who show up, baseline data on the rest)
3 - use baseline data on everyone
*/

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

use "data\codeddata\baseline\matched_baseline.dta", clear

*generate interaction term
gen logc_ST = logconsumption * selftargeting

* Number of bootstrap iterations
local bootstrapruns=100

* drop noise and old noisy pmt score
cap drop PMTSCORE_noise pcexppred_noise

* store bootstrap coefficient values and table results in this table
foreach panel in "a" "b"{
forv i=1/5{
	gen coef_`panel'`i'=.  // coefficient(s)
	gen N_`panel'`i'=.     // Observations
	gen MDV_`panel'`i'=.   // Mean of the dependent variable
	gen col_`panel'`i'=.       // table column
	gen col_`panel'`i'_sig=.   // significance levels
}
}

* column 2 has three coefficients to store per regression
	gen coef_a2_logc   =.
	gen coef_a2_logcst =.
	
	gen coef_b2_logc   =.
	gen coef_b2_logcst =.


qui forv x = 1/`bootstrapruns' {
	noi di "Bootstrap run no `x'"
	
* boostrap for column 1 in both panels, clustered at village level
	preserve
		bsample, cluster(hhea)
		sort hhid

	* generate noise and add to PMT score
	* using noise standard deviation = 0.45
	* see paper for details	
		gen noise = rnormal(0,0.45)
	
		gen PMTSCORE_noise = PMTSCORE + noise
		gen pce_sim = exp(PMTSCORE_noise)
		
	* getbenefit if qualify based on noisy PMT, and showed up if in ST 
		gen     getbenefit_h = pce_sim < povertyline3_noise_smooth
		replace getbenefit_h = 0 if showup==0 & selftargeting==1
		
	* Panel A column 1
		qui reg logconsumption selftargeting if getbenefit_h==1 
		matrix coef_a1 = e(b)
		sum logconsumption if e(sample)
		local MDV_a1 = r(mean)
		local N_a1 = r(N)
		
	* Panel B column 1
		qui areg logconsumption selftargeting if getbenefit_h==1, ab(kecagroup)
		matrix coef_b1 = e(b)
		sum logconsumption if e(sample)
		local MDV_b1 = r(mean)
		local N_b1 = r(N)
		
	restore
	
	sort hhid
	
	* Panel A column 1
	qui replace coef_a1 = coef_a1[1,1] in `x'
	qui replace N_a1 = `N_a1' 		   in `x'
	qui replace MDV_a1 = `MDV_a1'      in `x'
	
	* Panel B column 1
	qui replace coef_b1 = coef_b1[1,1] in `x'
	qui replace N_b1 = `N_b1' 		   in `x'
	qui replace MDV_b1 = `MDV_b1'      in `x'

	
* boostrap for columns 2-5 in both panels, clustered at kecamatan level
	preserve
		bsample, cluster(kecagroup)
		sort hhid

		gen noise = rnormal(0,0.45)
	
		gen PMTSCORE_noise = PMTSCORE + noise
		gen pce_sim = exp(PMTSCORE_noise)
		
	* getbenefit if qualify based on noisy PMT, and showed up if in ST 
		gen     getbenefit_h = pce_sim < povertyline3_noise_smooth
		replace getbenefit_h = 0 if showup==0 & selftargeting==1
		
	*generate errors for hypothetical beneficiaries
		gen     excl_error_h=0 if verypoor_povertyline1==1 & getbenefit_h==1
		replace excl_error_h=1 if verypoor_povertyline1==1 & getbenefit_h==0

		gen     incl_error_h=0 if  verypoor_povertyline1==0 & getbenefit_h==0
		replace incl_error_h=1 if  verypoor_povertyline1==0 & getbenefit_h==1

		gen     mistarget_h = excl_error_h
		replace mistarget_h = incl_error_h if mistarget_h==.
		
	* Panel A column 2
		qui logit getbenefit_h selftargeting logconsumption logc_ST
		matrix coef_a2 = e(b)
		sum getbenefit_h if e(sample)
		local MDV_a2 = r(mean)
		local N_a2 = r(N)
		
	* Panel A column 3	
		qui logit mistarget_h selftargeting
		matrix coef_a3 = e(b)
		sum mistarget_h if e(sample)
		local MDV_a3 = r(mean)
		local N_a3 = r(N)
	
	* Panel A column 4	
		qui logit excl_error_h selftargeting
		matrix coef_a4 = e(b)
		sum excl_error_h if e(sample)
		local MDV_a4 = r(mean)
		local N_a4 = r(N)
		
	* Panel A column 5		
		qui logit incl_error_h selftargeting 
		matrix coef_a5 = e(b)
		sum incl_error_h if e(sample)
		local MDV_a5 = r(mean)
		local N_a5 = r(N)
		
		
	* Panel B column 2
		qui clogit getbenefit_h selftargeting logconsumption logc_ST, group(kecagroup) 
		matrix coef_b2 = e(b)
		sum getbenefit_h if e(sample)
		local MDV_b2 = r(mean)
		local N_b2 = r(N)
		
	* Panel B column 3	
		qui clogit mistarget_h selftargeting, group(kecagroup) 
		matrix coef_b3 = e(b)
		sum mistarget_h if e(sample)
		local MDV_b3 = r(mean)
		local N_b3 = r(N)
	
	* Panel B column 4	
		qui clogit excl_error_h selftargeting, group(kecagroup)
		matrix coef_b4 = e(b)
		sum excl_error_h if e(sample)
		local MDV_b4 = r(mean)		
		local N_b4 = r(N)
		
	* Panel B column 5		
		qui clogit incl_error_h selftargeting, group(kecagroup) 
		matrix coef_b5 = e(b)		
		sum incl_error_h if e(sample)
		local MDV_b5 = r(mean)
		local N_b5 = r(N)
		
	restore
		
	sort hhid

	* Panel A column 2
	qui replace coef_a2        = coef_a2[1,1] in `x'
	qui replace coef_a2_logc   = coef_a2[1,2] in `x'
	qui replace coef_a2_logcst = coef_a2[1,3] in `x'
	qui replace N_a2 = `N_a2' 		   		  in `x'
	qui replace MDV_a2 = `MDV_a2'     		  in `x'

	* Panel A column 3
	qui replace coef_a3        = coef_a3[1,1] in `x'
	qui replace N_a3 = `N_a3' 		   		  in `x'
	qui replace MDV_a3 = `MDV_a3'     		  in `x'
	
	* Panel A column 4
	qui replace coef_a4        = coef_a4[1,1] in `x'
	qui replace N_a4 = `N_a4' 		   		  in `x'
	qui replace MDV_a4 = `MDV_a4'     		  in `x'
	
	* Panel A column 5
	qui replace coef_a5        = coef_a5[1,1] in `x'
	qui replace N_a5 = `N_a5' 		   		  in `x'
	qui replace MDV_a5 = `MDV_a5'     		  in `x'
	
	
	* Panel B column 2
	qui replace coef_b2        = coef_b2[1,1] in `x'
	qui replace coef_b2_logc   = coef_b2[1,2] in `x'
	qui replace coef_b2_logcst = coef_b2[1,3] in `x'
	qui replace N_b2 = `N_b2' 		   		  in `x'
	qui replace MDV_b2 = `MDV_b2'     		  in `x'

	* Panel B column 3
	qui replace coef_b3        = coef_b3[1,1] in `x'
	qui replace N_b3 = `N_b3' 		   		  in `x'
	qui replace MDV_b3 = `MDV_b3'     		  in `x'
	
	* Panel B column 4
	qui replace coef_b4        = coef_b4[1,1] in `x'
	qui replace N_b4 = `N_b4' 		   		  in `x'
	qui replace MDV_b4 = `MDV_b4'     		  in `x'
	
	* Panel B column 5
	qui replace coef_b5        = coef_b5[1,1] in `x'
	qui replace N_b5 = `N_b5' 		   		  in `x'
	qui replace MDV_b5 = `MDV_b5'     		  in `x'
	
	}
// end bootstrap

* summarize coefficients into table	
	sort hhid

	forv i=1/14{

		local    col: word `i' of "a1" "a2" "a2"      "a2"        "a3" "a4" "a5" "b1" "b2" "b2"      "b2"        "b3" "b4" "b5"
		local    var: word `i' of "a1" "a2" "a2_logc" "a2_logcst" "a3" "a4" "a5" "b1" "b2" "b2_logc" "b2_logcst" "b3" "b4" "b5"
		local r_mean: word `i' of 1    1    3         5           1    1    1    1    1    3         5           1    1    1
		local r_sd  : word `i' of 2    2    4         6           2    2    2    2    2    4         6           2    2    2
		
		* Input coefficients
		summ coef_`var'
		replace col_`col' = r(mean) in `r_mean'
		replace col_`col' = r(sd)   in `r_sd'
		
		* Input (average) number of observations
		summ N_`col'
		replace col_`col' = r(mean) in 8
		
		* Input (average) mean value of the dependent variable in the sample
		summ MDV_`col'
		replace col_`col' = r(mean) in 9
		
		* calculate level of significance
		if r(mean) < 0 {
			count if coef_`var' > 0 & coef_`var' < .
			replace col_`col'_sig = `r(N)'*2/`bootstrapruns' in `r_mean'
			}
		else {
			count if coef_`var' < 0
			replace col_`col'_sig = `r(N)'*2/`bootstrapruns' in `r_mean'
			}
		
	}


* add significance stars
foreach panel in "a" "b"{
forv i=1/5{
	//local    col: word `i' of "a1" "a2" "a2"      "a2"        "a3" "a4" "a5" "b1" "b2" "b2"      "b2"        "b3" "b4" "b5"
	local col "`panel'`i'"
	
	replace col_`col' = round(col_`col',.001)
   tostring col_`col', replace force format(%11.3f)
	replace col_`col' = col_`col' + "*" if col_`col'_sig < .1
	replace col_`col' = col_`col' + "*" if col_`col'_sig < .05 
	replace col_`col' = col_`col' + "*" if col_`col'_sig < .01
	
	foreach n in 2 4 6 {
		replace col_`col' = "(" + col_`col' + ")" in `n'
	}
}
}

* output table

	drop col_*_sig
	drop coef_*
	drop N_*
	drop MDV_*
	outsheet col_a1- col_b5 in 1/9 using "tables\Online Appendix Table C8.csv", replace comma


















