* Table 10: Impact of Alternative Targeting Approaches on the Poverty Gap

/*
Notation:

ST = self targeting treatment
PMT = automatic enrollment treatment
*/

clear all
pause on
set more off

set seed 2438279
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

******** Preparations

*** code benefit level for PMT households
*have child
	use "data\originaldata\baseline\hh_kp1",clear
	replace kp10=0 if kp10==3
	replace kp01=0 if kp01==3
	rename kp10 havechild
	la var havechild "binary; 1 if have a child"
	rename kp01 pregnancy
	la var pregnancy "binary; 1 if pregnant"
	keep hhid havechild pregnancy
	tempfile hh_kp1
	save `hh_kp1'
	
* information on kids for calculating true benefit
	use "data\originaldata\baseline\hh_ar2",clear
	gen count_inprimarysch=0
	replace count_inprimarysch=1 if ar19==1 & ar17==2
	la var count_inprimarysch "number of children in primary school"
	gen count_inmiddlesch=0
	replace count_inmiddlesch=1 if ar19==1 & ar17==3
	la var count_inprimarysch "number of children in middle school"
	collapse (sum) count_inprimarysch count_inmiddlesch, by(hhid)
	keep hhid count_inprimarysch count_inmiddlesch
	tempfile childeduc
	save `childeduc'
	
	
* workhours in order to construct wagerate for PMT
	use "data\originaldata\baseline\hh_ar2",clear
	
	*tab ar07 /*types of primary activity*/

	*tab ar09 /*number of hours per day on primary activity*/
	replace ar09=. if ar09>18

	*tab ar11 /*types of secondary activity*/

	*tab ar13 /*number of hours per day on secondary activity*/
	replace ar13=. if ar13>18
	replace ar13=0 if ar11==96 | ar11==6 | ar11==10 | ar11==11 | ar11==.
	replace ar09=0 if ar07==6 | ar07>=10 

	bys hhid: egen hr_primary_perday1=total(ar09), missing
	bys hhid: egen hr_secondary_perday1=total(ar13), missing

	bys hhid: egen hr_primary_perday=max(hr_primary_perday1)
	bys hhid: egen hr_secondary_perday=max(hr_secondary_perday1)

	duplicates drop hhid, force
	gen totworkhr_month=(hr_primary_perday+hr_secondary_perday)*30

	tempfile workhrs
	save	`workhrs'
		
* code benefit level for PMT households
	use "data\codeddata\baseline\matched_baseline.dta"
	
	merge 1:1 hhid using `hh_kp1'
	assert _m!=1
	keep if _m==3
	drop _m
	merge 1:1 hhid using `childeduc'
	assert _m!=1
	keep if _m==3
	drop _m
	merge 1:1 hhid using `workhrs'
	assert _m!=1
	keep if _m==3
	drop _m
	

	gen hh_benefit_yly=200000 /*baseline*/
		replace hh_benefit_yly=hh_benefit_yly+800000 if havechild==1|pregnancy==1
		replace hh_benefit_yly=hh_benefit_yly+400000 if count_inprimarysch > 0 & count_inprimarysch < .
		replace hh_benefit_yly=hh_benefit_yly+800000 if count_inmiddlesch > 0 & count_inmiddlesch < .
		replace hh_benefit_yly=600000 if hh_benefit_yly<600000
		replace hh_benefit_yly=2200000 if hh_benefit_yly>2200000
	la var hh_benefit_yly "yearly HH benefit"
		
	gen hh_benefit_mly = hh_benefit_yly/12
	la var hh_benefit_mly "monthly HH benefit"
		
	gen benefit = hh_benefit_mly/hhsize
	la var benefit "monthly per capita benefit"
		
	keep hhid benefit hh_benefit_mly hh_benefit_yly totworkhr_month
		
	tempfile benefitsPMT
	save	`benefitsPMT'
	
	
*** Main ST cost data
	u "data\codeddata\midline\costs.dta", clear
	keep if maintreatment==2
	keep hhid totcost_pc totcost_3k_pc totcost_6k_pc ave_waiting
	
	tostring hhid, replace
	forv x = 1/5 {
		replace hhid = "0"+hhid if length(hhid)<6
		}
	
	tempfile stcosts
	save 	`stcosts'


*** counterfactual showup probabilities
	insheet using "data\codeddata\matlab\MATLAB_showuphat.csv", comma clear	
	
	qui foreach v of varlist showup_hat* {
		cap replace `v'="" if regexm(lower(`v'),"n")
		cap destring `v', replace
		}
	tostring hhid, replace
	forv x = 1/5 {
		replace hhid = "0"+hhid if length(hhid)<6
		}
	g hhea = substr(hhid,1,3)
	tempfile counterf
	sa      `counterf'	
	
	

*** Poverty Gap of the various ST scenarios (based on showuphat)

* merge datasets
	use "data\codeddata\baseline\matched_baseline.dta", clear

* useful notation
	gen pmt= maintreatment==1
	gen  st= maintreatment==2
	keep if pmt | st

	merge 1:1 hhid using `stcosts'
	assert _m==3 | pmt
	drop _m

	egen kab_clas = group(kab urban)

* wagerate and benefits
	merge 1:1 hhid using `benefitsPMT'
	assert _m==3
	drop _m

* wagerate
	gen wagerate = consumption/totworkhr_month*hhsize

* obs with totworkhr_month==0, replace with 90th wage percentile
	qui sum wagerate, d
	replace wagerate = r(p90) if wagerate==. 

* add showup probabilities predicted using the model
	merge 1:1 hhid using `counterf'
	assert _m!=2 if st
	keep if _m==3 | pmt 
	// pause drop 29 observations in ST where we don't have showuphat predictions
	drop _m

* two observations
	drop if consumption==.



*** convert everything to per capita
* define showup hat and household costs
	gen benefit_mly = hh_benefit_mly / hhsize
	gen benefit_yly = hh_benefit_yly / hhsize
	rename consumption c
	rename povertyline1 pl

* need shorter names...
	rename showup     	  shh_rl
	rename showup_hat     shh_act
	rename showup_hat_km3 shh_km3
	rename showup_hat_km6 shh_km6
	rename showup_hat_3aw shh_aw3
	rename showup_hat_6aw shh_aw6
	gen    shh_pmt1 = shh_rl if pmt
	gen    shh_pmt2 = shh_rl if pmt

	replace shh_rl = . if pmt
	* gen the "perfect targeting" showup_idl after we make distribution in PMT and ST look the same

* define/repair per capita costs
	gen totcost_rl  = totcost_pc
	gen totcost_act = totcost_pc
	gen totcost_idl = totcost_pc

	gen totcost_km3 = totcost_3k_pc*(1-close) + totcost_rl*close
	gen totcost_km6 = totcost_6k_pc*(1-close) + totcost_rl*close

	gen totcost_aw3 = (2*ave_waiting*wagerate)/(60*hhsize)*(1-close) + totcost_rl
	gen totcost_aw6 = (5*ave_waiting*wagerate)/(60*hhsize)*(1-close) + totcost_rl

* define costs in automatic screening
* we assume the cost 15 minutes for any interviewed houshold
	gen totcost_pmt1 = wagerate * 0.25 / hhsize if pmt
	gen totcost_pmt2 = totcost_pmt1    			if pmt




*** expand data 
* in order to make PMT and ST consumption distributions the same
* and then to probabilistically assign realized showup and getbenefit
	keep hhid hhsize getbenefit PMTSCORE kab_clas pmt st c pl shh* benefit_mly hh_benefit_yly totcost_*

* predicted getbenefit using baseline PMT score
	probit getbenefit PMTSCORE i.kab_clas if shh_rl==1 & st
	predict pred_getb_st 

	probit getbenefit PMTSCORE i.kab_clas if shh_pmt1==1 & pmt
	predict pred_getb_pmt

* keep only observations where we have predictions
	drop if (pred_getb_st==. & st) | (pred_getb_pmt==. & pmt)

* keep only cells where we have both pmt and st
	bys kab_clas: egen npmt = sum(pmt)
	bys kab_clas: egen nst  = sum(st)

	drop if nst==0 | npmt==0
	drop nst npmt

** make consumption distribution in PMT and ST look exactly the same, by kabupaten x urban

* expand
	expand 1000, generate(subid)
	sort hhid subid 

	sort pmt kab_clas c subid
	bys  pmt kab_clas: gen rank = _n

	bys kab_clas: egen npmt = sum(pmt)
	bys kab_clas: egen nst  = sum(st)

* adjust rank if pmt has fewer/more observations
	replace rank = 1+(rank-1)*(nst-1)/(npmt-1) if pmt==1

* start from consumption in ST and (1) smooth in ST (where subid!=0) and (2) mimic the same in PMT
	gen newc = c if st==1 & subid==0
	bys kab_clas: ipolate newc rank, gen(newc2) e

	drop newc
	rename c c_old
	rename newc2 c

* adjust weights on kabupaten x urban to be the same in PMT and ST
	bys kab_clas: egen wt_pmt = sum(pmt)
	bys kab_clas: egen wt_st  = sum(st)

	gen     weight = wt_st/wt_pmt if pmt==1
	replace weight = 1 if st==1

	sum c [aw=weight] if pmt==1 & kab_clas == 1
	sum c [aw=weight] if st==1  & kab_clas == 1

	sum c [aw=weight] if pmt==1
	sum c [aw=weight] if st==1 

	sum c_old if pmt==1
	sum c_old if st==1	

	drop PMTSCORE kab_clas

* Perfect Targeting/ideal experiment (only poorest apply and all get it)
	gen shh_idl = (c < 0.8 * pl)

* the program is assumed to be implemented 80% in REAL (ST)
* this way none of the other variants gets implemented more than 100% 
	local fracreal=0.8
 
***

******** Create Table

* Analysis for Panel A, C, D, then B

/* corresponding columns in Table 10:
	"_rl" - column 3 (Self targeting Experimental)
	"_pmt1" - column 2 (Automatic Screening in sample costs Experimental)  
	"_pmt2" - column 1 (Automatic Screening scaled costs Experimental)  
	"_act" - column 4 (Baseline Model-Predicted Showup Probability)
	"_km3" - column 5 (Far Distance + 3km Model-Predicted Showup Probability)
	"_km6" - column 6 (Far Distance + 6km Model-Predicted Showup Probability)
	"_aw3" - column 7 (Far Wait Time *3 Model-Predicted Showup Probability)
	"_aw6" - column 8 (Far Wait Time *6 Model-Predicted Showup Probability)
	"_idl" - column 9 (Perfect Targeting)
*/		
		
		
gen results_la = ""
forv i=1/9{
local suff	: word `i' of "rl" "pmt1" "pmt2" "act" "km3" "km6" "aw3" "aw6" "idl"
local   tr	: word `i' of "st" "pmt"  "pmt"  "st"  "st"  "st"  "st"  "st"  "st"  // treatment
	
	noisily di "`suff'"

	*** administrative cost of treatment
		* using popPMT = 255,632 households (q L11 in baseline listing) 
		* and   popST  = 240,756 households
		* cost per village is 854 USD in the experiment (scale by showup)
		* exchange rate used 1 USD = 9,535 Rp.
		 
		local hhST  = 240756		
		local hhPMT = 255632
		local nSLS  = 3651.5
		
		* results table 
		gen results_`suff'=.
		
		
		
*** PANEL A - Program Stats

	sum shh_`suff' if `tr' [aw=weight]
	local showup_suff = r(mean)
	
* log: fraction who show up
	replace results_`suff' = r(mean) in 1
	replace results_la = "Mean show up rate" in 1
				
	gen temp = shh_`suff'*pred_getb_`tr'
	sum temp if `tr' [aw=weight]
			
* log: fraction of benefit recipients 
	replace results_`suff' = r(mean) in 2
	replace results_la = "Mean benefit receipt" in 2
	drop temp
				
	gen temp = shh_`suff'*pred_getb_`tr'*(c < 0.8*pl)
	sum temp if `tr' [aw=weight]
	
* log: fraction of eligible benefit recipients
	replace results_`suff' = r(mean) in 3
	replace results_la = "Mean eligible benefit receipt" in 3
	drop temp
			
	gen temp = shh_`suff'*pred_getb_`tr'*(c >= 0.8*pl)
	sum temp if `tr' [aw=weight]
* log: fraction of IN-eligible benefit recipients
	replace results_`suff' = r(mean) in 4 //23
	replace results_la = "Mean ineligible benefit receipt" in 4 //23
	drop temp		
			
	* count beneficiaries directly in "ideal scenario"
	if("`suff'"=="idl"){
		count if (c < 0.8 * pl) & `tr' 
		local poor = r(N)
		count if st
		local all  = r(N)
* log: fraction of benefit recipients 
		replace results_idl = `poor'/`all' in 2
* log: fraction of eligible benefit recipients	
		replace results_idl = `poor'/`all' in 3
* log: fraction of IN-eligible benefit recipients
		replace results_idl = 0 in 4 //23
	}
		
		
*** PANEL C - admin costs		
		if("`suff'"=="pmt1"){            // PMT: in sample cost per hh = (cost per SLS) * number of SLS / (total #hh)
			gen admin_cost_perhh_pmt1 = (228 * 9535) * (`nSLS') / (`hhPMT')
		}
		else if("`suff'"=="pmt2"){       // PMT: at scale cost per hh = 0.5$			
			gen admin_cost_perhh_pmt2 = (0.5 * 9535) 
		}
		else{ // ST: cost per hh = (cost per village) * (scale up factor b/c of different show up rate) / #hh
			sum shh_rl [aw=weight] if st
			local showup_rl = r(mean)
			gen admin_cost_perhh_`suff' = (854 * 9535) * (200 * `showup_suff' / `showup_rl') / `hhST'
			}
		
* log: government admin costs per hh	
	replace results_`suff' = admin_cost_perhh_`suff'[1] in 10 //5
	replace results_la = "Administraive costs, per hhd" in 10 //5

	* expected benefit 
	gen     exp_benefit_`suff' = hh_benefit_yly * 6 * pred_getb_`tr' * shh_`suff'
	replace exp_benefit_`suff'=. if !`tr'
		
	if("`suff'"=="idl"){
		replace exp_benefit_idl = hh_benefit_yly * 6 * (c < 0.8 * pl) if `tr'
	}
		
	sum exp_benefit_`suff' if `tr' [aw=weight]
	gen avg_bencost_`suff' = r(mean)
	
* log: government costs of paying benefits 
	replace results_`suff' = r(mean) in 11 //6
	replace results_la = "Expected benefits, per hhd" in 11 //6
	
	
	* total cost = admin cost + average benefits
	gen totadmincost_`suff' = admin_cost_perhh_`suff' + avg_bencost_`suff'
	sum totadmincost_`suff' if `tr' [aw=weight]
	
* log: total govt costs
	replace results_`suff' = r(mean) in 12 //7
	replace results_la = "Total Program Cost,  Rp. per hhd" in 12 //7

* log: total govt costs per showup
	replace results_`suff' = r(mean)/results_`suff'[1] in 15 //10 
	replace results_la = "Total Program Cost,  Rp. per hhd that shows up" in 15 //10

* log: total govt costs per beneficiary hh
	replace results_`suff' = r(mean)/results_`suff'[2] in 16 //11 
	replace results_la = "Total Program Cost,  Rp. per hhd that shows up" in 16 //11
			
			
	* Fix fraction implemented in REAL to 90% (`fracreal') so we don't go over 100% anywhere	
	* totaladmincost_rl is defined in the first run through the loop
	gen frac_trt_`suff' = `fracreal' * totadmincost_rl/totadmincost_`suff'
	sum frac_trt_`suff' if `tr' [aw=weight]
		
* log: fraction implemented
	replace results_`suff' = r(mean) in 13 //8
	replace results_la = "Fraction of Program implemented" in 13 //8
		
		
*** assign realized (rzd) showup and get benefit
	local seed=1212+864*`i'
	set seed `seed'
	gen draw1 = runiform()
	gen draw2 = runiform()

	gen rzd_`suff'    = (draw1 < shh_`suff')                   if `tr'
	gen rzd_gb_`suff' = rzd_`suff' * (draw2 < pred_getb_`tr')  if `tr'

	if("`suff'"=="idl"){
	replace rzd_gb_idl = (c < 0.8 * pl) if `tr'
	}

	*** consumption with benefit and with cost
	gen c_ben_`suff' = c + benefit_mly    * rzd_gb_`suff' if `tr'
	gen c_cst_`suff' = c - totcost_`suff' * rzd_`suff'    if `tr'

	* alternative total costs per eligible beneficiary
	cap drop temp
	gen temp = (rzd_gb_`suff'==1) * (c < 0.8 * pl)
	sum temp if `tr' [aw=weight]

* log: total govt costs per eligible beneficiary hh
replace results_`suff' = results_`suff'[/*7*/12]/r(mean) in 17 //12 // total costs per *eligible* beneficiary household
replace results_la = "Total Program Cost,  Rp. per eligible beneficiary hhd" in 17 //12

	drop temp	

	
	*** calculate individual contribution to poverty gap
	* baseline (based on original consumption)
	cap drop povgap_baseline
	g       povgap_baseline = (pl - c) / pl if `tr'
	replace povgap_baseline = 0   if c > pl &  `tr' 

	* benefits only and costs only
	foreach va in ben cst{
	g       povgap_`va'_`suff' = (pl - c_`va'_`suff') / pl if `tr' //& c_`va'_`suff' != . 
	replace povgap_`va'_`suff' = 0   if c_`va'_`suff' > pl &  `tr' //& c_`va'_`suff' != .
	}

	*** combine different poverty gaps into one measure 
	* (steady state assumption so there is no discounting)
	* one month of costs, 11 of waiting and 6 years of benefits
	* we're assuming the program is implemented in all villages
	g povgap_`suff'_full = (povgap_cst_`suff' + 11*povgap_baseline + 12*6*povgap_ben_`suff')/(12*7)

	*** adjust for fixed budget (program only implemented in a fraction of villages)
	g povgap_`suff' = frac_trt_`suff'*povgap_`suff'_full + (1-frac_trt_`suff')*povgap_baseline
	
	format results_`suff' %10.0g
	
	
*** PANEL D: poverty gaps

	* log: poverty gap at baseline 
		sum povgap_baseline if `tr' [aw=weight]
		replace results_`suff' = r(mean) in 19 //13
		replace results_la = "Poverty Gap at baseline" in 19 //13

	* log: poverty gap counting benefits only	
		sum povgap_ben_`suff' if `tr' [aw=weight]
		replace results_`suff' = r(mean) in 20 //14
		replace results_la = "Poverty Gap (benefits only)" in 20 //14

	* log: poverty gap counting costs only
		sum povgap_cst_`suff' if `tr' [aw=weight]
		replace results_`suff' = r(mean) in 21 //15
		replace results_la = "Poverty Gap (costs only)" in 21 //15
		
	* log: poverty gap with full implementation (no budget limitation)
		sum povgap_`suff'_full if `tr' [aw=weight]
		replace results_`suff' = r(mean) in 22 //16
		replace results_la = "Poverty Gap (full implementation)" in 22 //16

	* log: poverty gap under fixed budget
		sum povgap_`suff' if `tr' [aw=weight]
		replace results_`suff' = r(mean) in 23 //17
		replace results_la = "Poverty Gap under fixed budget" in 23 //17	
	

*** PANEL B - costs to households

	* add costs per hh, for beneficiaries and non-benefs
	gen totcost_hh_`suff' = hhsize * totcost_`suff'
	
* log: cost if showup
	sum totcost_hh_`suff' if rzd_`suff'==1     & `tr' [aw=weight]
	replace results_`suff' = r(mean) in 6 //19
	replace results_la = "Average cost to households" in 6 //19


* log: cost if (showup and) getbenefit
	sum totcost_hh_`suff' if rzd_gb_`suff'==1  & `tr' [aw=weight]
	replace results_`suff' = r(mean) in 7 //20
	replace results_la = "Average cost to beneficiary hhds" in 7 //20

* log: cost if showup and not get benefit
	sum totcost_hh_`suff' if rzd_`suff'==1 & rzd_gb_`suff'==0  & `tr' [aw=weight]
	replace results_`suff' = r(mean) in 8 //21	
	replace results_la = "Average cost to non-beneficiary hhds" in 8 //21
		
	
* free some memory
	drop  admin_cost_perhh_`suff'- avg_bencost_`suff' frac_trt_`suff'- povgap_`suff'
	
	if("`suff'"!="rl"){
		drop totadmincost_`suff'
	}
}


* log: Reduction in Poverty Gap relative to perfect targeting	
replace results_la = "Reduction in Poverty Gap relative to perfect targeting" in 25

forv i=1/9{
	local suff	: word `i' of "rl" "pmt1" "pmt2" "act" "km3" "km6" "aw3" "aw6" "idl"
	* Reduction = (Poverty Gap under fixed budget - Poverty Gap at baseline)
	replace results_`suff' = (results_`suff'[23] - results_`suff'[19])/(results_idl[23] - results_idl[19]) in 25	
}


order results*
outsheet results* in 1/25 using "tables\Table 10.csv", replace comma




