function [W,all_params] = GMM_problem(delta_mom, danual, irate, eta_sd, passes, rng_seed,sample)
% Two Stage Feasible GMM for Targeting Paper

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters:
% 1~2. mean, variance of epsilon (utility shock);
% 3. sigma (coef of relative risk aversion = rho, sorry for the confusion);
% 4. alpha (fraction of people who are sophisticated)
% 5~6. constant and coefficient for the lambda function (probability of getting benefit given showing up)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Minimize Objective Function Locally From Many Starting Values
%	Use matlab's built-in lsqnonlin function to optimize from a random set 
%	of initial values.

%% How are moments computed?
%	For each obs, calculate showup_hat as the probability that eps>-gain 
%	(i.e. that gain+epsilon>0) This is just 1 - the cdf
%	of epsilon evaluated at (-gain_i).

%% What is gain?
% Gain is actually Net Gain from the paper: it is (utility a person would get from showing up) - (utility from not showing up).
% This is a combination of present and future utility. We assume that the person is trading off the present month's utility for 6 years of future utility, which come in annual discounted installments.
% e.g. U(not showup) = U(PCE) + 12*delta*U(PCE)
% Net Gain = U(showup) - U(not showup)
% delta = NPV coefficient

% load data as globals
small_sample_dummy = 0; % use regular data for estimation
load_data(sample,small_sample_dummy);

global consumption
global lambda_con_true lambda_beta_true
if isempty(consumption)
    error('Did not lead data before calling GMM objective function');
end

% Initialize random number generator
rng(rng_seed);

% generate random sets of #passes possible initial values for each parameter
    % "get benefit" function, lambda for the naive people
    lambda_con_rand = lambda_con_true*(0.8+0.4*rand(passes,1));
    lambda_beta_rand = lambda_beta_true*(0.8+0.4*rand(passes,1)); % These two are parameters to match the initial value

    % legacy - ensures same random numbers are generated as in a previous
    % version
    %rand(passes,1);

    % Currently imposing some function of random rho + noise
    sig_eps_rand = 26805.*(0.8+0.4*rand(passes,1)); 
    mu_eps_rand = -26215.*(0.8+0.4*rand(passes,1));
    
    alpha_rand = 0.001+0.999*rand(passes,1);

% compute NPV delta (yearly)
irm = 1/irate;
delta = danual*(1 + irm + irm^2 + irm^3 + irm^4 + irm^5);


%% First Stage: Find params with identity weighting matrix
disp('First Stage Begin');

Fval_fs = zeros(passes,1);
Fitparams_fs = zeros(passes,5);
Showup_hat_fs     = zeros(size(consumption,1),passes);
Induced_lambda_fs = zeros(size(consumption,1),passes);
exitflag_fs       = zeros(passes,1);

for pass = 1:passes
    tic;
    % select initial parameters
    params_in = [   mu_eps_rand(pass,1),...
                    sig_eps_rand(pass,1),...
                    alpha_rand(pass,1),...
                    lambda_con_rand(pass,1),...
                    lambda_beta_rand(pass,1)]; 

    % begin with identity weigthing matrix 
    W0 = eye(20);
    
    [Fitparams_fs(pass,:), Fval_fs(pass), Showup_hat_fs(:,pass), Induced_lambda_fs(:,pass), exitflag_fs(pass)] = ...
        run_GMM(  params_in, eta_sd, delta, W0, delta_mom );
    
    disp(['First Stage pass # ' num2str(pass) ' took ' num2str(toc)]);
end

[~, minindex] = min(Fval_fs);
params_fs         =      Fitparams_fs(minindex,:);
% showuphat_fs      =     Showup_hat_fs(:,minindex);
% induced_lambda_fs = Induced_lambda_fs(:,minindex);

%% Second Stage: Find Params with Optimal Weighting Matrix
disp('Second Stage Begin')
% Calculate Optimal Weighting Matrix
% GMM_obj using W0 = identity returns the moment values

    %params_fs = [-67020	60897	0.22044	8.6504	-0.77535];
     mu_eps  = params_fs(1);
     sig_eps = params_fs(2);
     alpha   = params_fs(3);
     lambda_con_belief  = params_fs(4);
     lambda_beta_belief = params_fs(5);

    [ showup_hat, induced_lambda ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);

    belief_lambda  = normcdf(lambda_con_belief+lambda_beta_belief*log(consumption));
    true_lambda    = normcdf(lambda_con_true  +lambda_beta_true  *log(consumption));

    moms = moments( showup_hat, true_lambda, belief_lambda, induced_lambda, delta_mom );

    N = size(consumption,1);
    Winv = (moms'*moms)/N;
    W = inv(Winv);
    Whalf = chol(W)';
    norm((Whalf*Whalf')-W) %check decomposition worked.
    clear mu_eps sig_eps alpha lambda_con_belief lambda_beta_belief;
    
Fval_ss           = zeros(passes,1);    
Fitparams_ss      = zeros(passes,5);
Showup_hat_ss     = zeros(size(consumption,1),passes);
Induced_lambda_ss = zeros(size(consumption,1),passes);
exitflag_ss       = zeros(passes,1);

for pass = 1:passes
    tic;
    % select initial parameters (the same ones as in first stage)
    params_in = [   mu_eps_rand(pass,1),...
                    sig_eps_rand(pass,1),...
                    alpha_rand(pass,1),...
                    lambda_con_rand(pass,1),...
                    lambda_beta_rand(pass,1)]; 

    % use optimal weigthing matrix Whalf 
    [Fitparams_ss(pass,:), Fval_ss(pass), Showup_hat_ss(:,pass), Induced_lambda_ss(:,pass), exitflag_ss(pass)] = ...
        run_GMM(  params_in, eta_sd, delta, Whalf, delta_mom );
    
    disp(['Second Stage pass # ' num2str(pass) ' took ' num2str(toc)]);
end

[~, minindex] = min(Fval_ss);
ismax = (1:passes)==minindex;
% params_ss = Fitparams_ss(minindex,:);
%showup__hat = Showup_hat_ss(:,minindex);
%induced_lambda_ss = Induced_lambda_ss(:,minindex);

all_params = [mu_eps_rand, Fitparams_fs(:,1), Fitparams_ss(:,1), ...
              sig_eps_rand,Fitparams_fs(:,2), Fitparams_ss(:,2),...
              alpha_rand,  Fitparams_fs(:,3), Fitparams_ss(:,3),...
              lambda_con_rand,  Fitparams_fs(:,4), Fitparams_ss(:,4),...
              lambda_beta_rand, Fitparams_fs(:,5), Fitparams_ss(:,5),...
              Fval_fs, Fval_ss, exitflag_fs, exitflag_ss, ismax'];
              
disp('Second Stage Done');


end